#
# spec file for package gnuhealth-client
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2015-2024 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define majorver 4.4

%if 0%{?suse_version} >= 1550
%define pythons python3
%define mypython python3
%define mysitelib %python3_sitelib
%else
%{?sle15_python_module_pythons}
%define mypython %pythons
%define mysitelib %{expand:%%%{mypython}_sitelib}
%endif

Name:           gnuhealth-client
Version:        %{majorver}.0
Release:        1.6
Summary:        The client of the GNU Health Hospital system
License:        GPL-3.0-only
Group:          Productivity/Office/Management
URL:            http://health.gnu.org/
Source:         https://ftp.gnu.org/pub/gnu/health/%{name}-%{version}.tar.gz
## Source:         %{name}-%{version}.tar.gz
## Source1:        %{name}-plugins-%{version}.tar.gz
Source1:        ftp://ftp.gnu.org/gnu/health/plugins/gnuhealth_plugin_camera-latest.tar.gz
Source2:        ftp://ftp.gnu.org/gnu/health/plugins/gnuhealth_plugin_crypto-latest.tar.gz
Source3:        ftp://ftp.gnu.org/gnu/health/plugins/gnuhealth_plugin_frl-latest.tar.gz

Source5:        https://ftp.gnu.org/gnu/health/%{name}-%{version}.tar.gz.sig
Source6:        https://savannah.gnu.org/project/memberlist-gpgkeys.php?group=health&download=1#/%{name}.keyring

BuildRequires:  %{mypython}-Babel
BuildRequires:  %{mypython}-Sphinx
BuildRequires:  %{mypython}-devel
BuildRequires:  %{mypython}-gobject
BuildRequires:  %{mypython}-pip
BuildRequires:  %{mypython}-python-dateutil
BuildRequires:  %{mypython}-setuptools
BuildRequires:  %{mypython}-simplejson
BuildRequires:  %{mypython}-wheel
BuildRequires:  fdupes
BuildRequires:  update-desktop-files

Requires:       %{mypython}-GooCalendar >= 0.5
Requires:       %{mypython}-cairo
Requires:       %{mypython}-chardet
Requires:       %{mypython}-dateutil
Requires:       %{mypython}-python-gnupg
Requires:       %{mypython}-gobject
Requires:       %{mypython}-gobject-Gdk
Requires:       %{mypython}-gobject-cairo
Requires:       %{mypython}-numpy
Requires:       %{mypython}-opencv
Requires:       %{mypython}-pytz
Requires:       %{mypython}-setuptools
Requires:       %{mypython}-simplejson
Requires:       %{mypython}-xml
Requires:       gnu-free-fonts
Requires:       gobject-introspection
Requires:       opencv

BuildArch:      noarch

## Conflicts:      tryton

%description
The client of the GNU Health Hospital application

%prep
%setup -q

pwd
cd gnuhealth/plugins
tar  -xzvf %{SOURCE1}
tar  -xzvf %{SOURCE2}
tar  -xzvf %{SOURCE3}

#workaround for tryton bug: directory name with version is not considered
mv gnuhealth_camera* camera
## mv gnuhealth_crypto* crypto
##  mv gnuhealth_frl* frl

# Remove pycache
rm -rf */__pycache__

#shebag ersetzen
find . -iname "bin/gnuhealth-client" -exec sed -i "s/env python/%{mypython}/" '{}' \;

%build
%pyproject_wheel

%install
%pyproject_install

# menu-entry
desktop-file-install --dir %{buildroot}%{_datadir}/applications %{name}.desktop
%suse_update_desktop_file %{name}

mkdir -p %{buildroot}%{_datadir}/pixmaps

cp %{buildroot}%{mysitelib}/gnuhealth/data/pixmaps/gnuhealth/gnuhealth-icon.png %{buildroot}%{_datadir}/pixmaps/gnuhealth.png

%python_expand %fdupes %{buildroot}%{python3_sitelib}

%files
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%doc Changelog
%license COPYRIGHT COPYING
%{_datadir}/pixmaps/*
%{mysitelib}/gnuhealth
%{mysitelib}/gnuhealth_client-%{version}.dist-info

%changelog
* Sat Jan  6 2024 Axel Braun <axel.braun@gmx.de>
- version 4.4.0
  For details see Changelog
  switch to wheel build
* Sat Jan  6 2024 Ben Greiner <code@bnavigator.de>
- Enable to SLE15 python module pythons
* Thu Dec 21 2023 Axel Braun <axel.braun@gmx.de>
- version 4.2.1
  * Various Tryton-patches applied, see Changelog for details
* Tue Oct 17 2023 Daniel Garcia Moreno <daniel.garcia@suse.com>
- Remove %%python3_install prefix and root options, that's included in
  the macro by default.
* Sun Feb 12 2023 Axel Braun <axel.braun@gmx.de>
- verion 4.2.0
  * Instance and connection information visible at the GTK client title
  * Add GNUHEalth scalable icon - svg - for desktop menu and panel entries
  * see Changelog for full description
  * separate gnuhalth-client.desktop file removed
* Thu Jun 16 2022 Axel Braun <axel.braun@gmx.de>
- version 4.0.1
  * various bug fixes, see changelog
  * plugins adapted and renamed for 4.0
* Sun Mar  6 2022 Axel Braun <axel.braun@gmx.de>
- version 4.0.0
  * based on Tryton 6.0
  * for details see CHANGELOG
* Sat Feb 27 2021 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key and verify source signature
* Thu Feb 25 2021 Axel Braun <axel.braun@gmx.de>
- python_dependency_generator removed (misses dependencies....)
* Mon Feb 15 2021 Axel Braun <axel.braun@gmx.de>
- version 3.8.1
  spec-file updated to use new python macros
* Sat Nov  7 2020 Axel Braun <axel.braun@gmx.de>
- remove __pycache__ from plugins (boo#1178453)
* Sun May 17 2020 Axel Braun <axel.braun@gmx.de>
- version 3.6.9
  various bugfixes (including boo#1170553)
* Sun Mar  1 2020 Axel Braun <axel.braun@gmx.de>
- version 3.6.8
  * Removed the deprecated App Menu in favor of the Menu Bar.
  * Migrate from obsolete Table to Grid
  * Fix the footer
  * Include accelerator for preferences (ctrl+shift+p) and fix
    accelerator for shortcuts (ctrl+shift+F1)
  * Avoid maximizing application at startup
  * Remove unused fast tabbing option from menu
  * Allow setting the GH command line on the bottom again (cli_position =
    bottom). By default is top.
* Fri Jan 31 2020 Axel Braun <axel.braun@gmx.de>
- version 3.6.6
  * Fix bug #57682: GTK Client - CLI is activated when pressing Shift+Z
  * Add GNU Health shortcuts to the help window
* Thu Jan  2 2020 Axel Braun <axel.braun@gmx.de>
- update frl plugin to 3.6.1
* Tue Dec 24 2019 Axel Braun <axel.braun@gmx.de>
- version 3.6.5: Fix variable name to values
* Sat Dec  7 2019 Axel Braun <axel.braun@gmx.de>
- version 3.6.4 #57371  Error when assigning a health professional on the work schedule
* Mon Dec  2 2019 Axel Braun <axel.braun@gmx.de>
- version 3.6.3 - various performance improvements
* Sun Dec  1 2019 Axel Braun <axel.braun@gmx.de>
- version 3.6.2 - various bugfixes
* Thu Nov 21 2019 Axel Braun <axel.braun@gmx.de>
- version 3.6.0
* Mon Nov 11 2019 Axel Braun <axel.braun@gmx.de>
- camera.diff added
  plugins changed from *latest* to version 3.4.x
* Thu Jul 11 2019 Axel Braun <axel.braun@gmx.de>
- plugin_frl updated to version 3.4.1
* Sat Apr 20 2019 Axel Braun <axel.braun@gmx.de>
- version 3.4.4 - Security fix boo#1131707
* Tue Apr  2 2019 Axel Braun <axel.braun@gmx.de>
- link to python2-GooCalendar (remains python2) boo#1131096
* Sun Jan 27 2019 Axel Braun <axel.braun@gmx.de>
- Version 3.4.3
  * Fix bug #55458: Command line gets activated with shift Z
  * many bugfixes from tryton client
* Fri Dec 28 2018 Axel Braun <axel.braun@gmx.de>
- version 3.4.2 with many bugfixes
* Tue Dec 11 2018 Axel Braun <axel.braun@gmx.de>
- New client for the GNU Health 3.4 series based on Tryton 4.6 series
  * Enhanced support for Calendar and WebDAV system
  * Native client has a command line interface
  * Over 30 new commands for the main daily tasks
  * Enhanced GNU Health camera plugin, including zoom
  * gnuhealth_crypto.patch replaced by plugin
  * Activity Log window on the client
  * SYSINFO command to retrieve the information about client and server
  * Customize the banner on the client
* Fri Mar 16 2018 axel.braun@gmx.de
- Bugfix Release 3.2.6
* Mon Jan 29 2018 tchvatal@suse.com
- Add emptly build phase to silence rpmlint
- Drop python-rsvg require, the code does not include it
* Fri Jan  5 2018 axel.braun@gmx.de
- GNU Health client - initial version 3.2.5
